# Setting Up the OData Integration with Business Intelligence Tools
### On this page
  * [Video Tutorial for Microsoft Power BI and Tableau](https://help.sap.com/docs/leanix/ea/setting-up-odata-integration-with-business-intelligence-tools#video-tutorial-for-microsoft-power-bi-and-tableau)
  * [Microsoft Power BI](https://help.sap.com/docs/leanix/ea/setting-up-odata-integration-with-business-intelligence-tools#microsoft-power-bi)
  * [Changing Authentication Credentials for an OData Feed](https://help.sap.com/docs/leanix/ea/setting-up-odata-integration-with-business-intelligence-tools#changing-authentication-credentials-for-an-odata-feed)
  * [Using Dataflows](https://help.sap.com/docs/leanix/ea/setting-up-odata-integration-with-business-intelligence-tools#using-dataflows)
  * [Tableau](https://help.sap.com/docs/leanix/ea/setting-up-odata-integration-with-business-intelligence-tools#tableau)
  * [SAP Tools](https://help.sap.com/docs/leanix/ea/setting-up-odata-integration-with-business-intelligence-tools#sap-tools)


Learn how to configure the OData integration with popular business intelligence tools to streamline data access and enhance analytics capabilities.
